@@ -204,19 +204,19 @@ def copyfile(src, dst, env):
     """
     copyfile
     """
-    return copyfile(sformat(src,env), sformat(dst,env))
+    return shutil.copyfile(sformat(src,env), sformat(dst,env))
 
 def copyshp(src, dst, env):
     """
     copyshp
     """
     src,dst = sformat(src, env),sformat(dst, env)
-    res = copyfile(src, dst)
+    res = copyfile(src, dst, env)
     if justpath(src).lower()=="shp":
         for ext in ("dbf","shx","prj","qpj"):
             src = forceext(src,ext)
             if os.path.isfile(src):
-                copyfile(src, forceext(dst,ext))
+                copyfile(src, forceext(dst,ext), env)
     return res
 
 def remove(files):
